; docformat = 'rst'
;+
; This is an example program to demontrate how to create a 2D scatter plot
; with Coyote Graphics routines.
;
; :Categories:
;    Graphics
;    
; :Examples:
;    Save the program as "scatter_plot_2d.pro" and run it like this::
;       IDL> .RUN scatter_plot_2d
;       
; :Author:
;    FANNING SOFTWARE CONSULTING::
;       David W. Fanning 
;       1645 Sheely Drive
;       Fort Collins, CO 80526 USA
;       Phone: 970-221-0438
;       E-mail: david@idlcoyote.com
;       Coyote's Guide to IDL Programming: http://www.idlcoyote.com
;
; :History:
;     Change History::
;        Written, 23 January 2013 by David W. Fanning.
;
; :Copyright:
;     Copyright (c) 2013, Fanning Software Consulting, Inc.
;-
PRO Scatter_Plot_2D
 
   ; Create the random data. Set the seed so you see what I see.
   time = cgDemoData(1)+ RandomU(-3L, 101) * 10
   grade = cgDemoData(1)+ RandomU(seed, 101) * 20 + 50
    
   ; Set up variables for the plot. Normally, these values would be 
   ; passed into the program as positional and keyword parameters.
   xtitle = 'Study Time (minutes)'
   ytitle = 'Quiz Grade'
   color = 'CornFlower Blue'
   symbol = 16
   fillcolor = 'Rose'
   maxValue = Round(Max(time) * 1.1)

   ; Draw the scatter plot
   cgScatter2D, time, grade, XTitle=xtitle, YTitle=ytitle, $
      Color=color, PSym=symbol, FillColor=fillcolor, XRange=[0,maxValue]
                
END ;*****************************************************************

; This main program shows how to call the program and produce
; various types of output.

  ; Display the plot in a graphics window.
  Scatter_Plot_2D
  
  ; Display the plot in a resizeable graphics window.
  cgWindow, 'Scatter_Plot_2D', WTitle='2D Scatter Plot in a Resizeable Graphics Window'
  
  ; Create a PostScript file.
  cgPS_Open, 'scatter_plot_2d.ps'
  Scatter_Plot_2D
  cgPS_Close
  
  ; Create a PNG file with a width of 600 pixels.
  cgPS2Raster, 'scatter_plot_2d.ps', /PNG, Width=600

END